@@ -6,7 +6,6 @@ require 'hamlit/escapable'
 require 'hamlit/force_escapable'
 require 'hamlit/html'
 require 'hamlit/string_splitter'
-require 'hamlit/static_analyzer'
 
 module Hamlit
   class Engine < Temple::Engine
@@ -27,7 +26,7 @@ module Hamlit
     use Compiler
     use HTML
     use StringSplitter
-    use StaticAnalyzer
+    filter :StaticAnalyzer
     use Escapable
     use ForceEscapable
     filter :ControlFlow
